package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(P``````````0```````
M`+&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*M8````````JU@`
M```````0``````$````&````````J[@```````"[N````````+NX````````
M!-`````````$^````````!```````@````8```````"KR````````+O(````
M````N\@````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````I$@```````"D2````````*1(`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*NX````````N[@`````
M``"[N`````````1(````````!$@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`CO4TZ!I5*K+\3;FZXY&/,@]'7G0````$````$```
M``%'3E4```````````,````"```````````````1````0P````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D"`(F""`(`ND$0@(@`````````0P```$8```!)
M````2@```%(```!3````5`````````!6````5P```%@```!9````6@```%P`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,
M%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````````````
M```````````#```+````````&5```````````````W02````````````````
M`````````````I\2`````````````````````````````(P1````````````
M`````````````````<,2`````````````````````````````@82````````
M`````````````````````H82`````````````````````````````+T2````
M`````````````````````````D(2``````````````````````````````$@
M`````````````````````````````G\2````````````````````````````
M`&<2`````````````````````````````;82````````````````````````
M`````,82`````````````````````````````M$2````````````````````
M`````````842`````````````````````````````?82````````````````
M`````````````2D2`````````````````````````````6H2````````````
M`````````````````)02`````````````````````````````!`@````````
M`````````````````````K<2`````````````````````````````2`2````
M`````````````````````````(H1`````````````````````````````3<2
M`````````````````````````````"P@````````````````````````````
M`)T2`````````````````````````````JD2````````````````````````
M`````4T2`````````````````````````````.$6````````````````````
M`````````/02`````````````````````````````7X2````````````````
M`````````````E42`````````````````````````````0\2````````````
M`````````````````L(2`````````````````````````````+,2````````
M`````````````````````%@B`````````````````````````````=`2````
M`````````````````````````;$2`````````````````````````````3X2
M`````````````````````````````<H2````````````````````````````
M`6,2`````````````````````````````:(2````````````````````````
M`````I$2`````````````````````````````B<2````````````````````
M`````````'D2`````````````````````````````7<2````````````````
M`````````````>$2`````````````````````````````)P2````````````
M`````````````````-H2`````````````````````````````A(2````````
M`````````````````````;X2`````````````````````````````G,2````
M`````````````````````````J02`````````````````````````````>\2
M`````````````````````````````F81````````````````````````````
M`8P2`````````````````````````````*02````````````````````````
M`````,P2`````````````````````````````002````````````````````
M`````````542`````````````````````````````*L2````````````````
M`````````````C,2`````````````````````````````$82````````````
M`````````````````902`````````````````````````````9L1````````
M`````````````````````WT2```-````````7T``````````V````](2```-
M````````5"`````````(S@```%,2```-````````('`````````"D````O02
M```-````````1"``````````!@```Q(2```-````````7/`````````"2```
M`_@2```-````````1#`````````#M@```[@0```7````````P(@`````````
M`````P42```-````````1_``````````/@```R@2```-````````3W``````
M````@````XD1```/````````8X``````````!````Z42```-````````8(``
M```````!/````[`2```-````````0O``````````.````\T0```7````````
MP+```````````````^82```-````````4I`````````!D```!`\2```-````
M````3_``````````@@```Y@0```6````````P````````````````TP2```-
M````````2#`````````!D@```]\0```7````````P(@`````````````!`41
M```6````````P(``````````"````YX2```-````````(P``````````````
M`\02```-````````8"``````````7@```YH@```6````````P```````````
M`````V(2```-````````4E``````````-@```S82```-````````0S``````
M````Z@```U@2```-````````8<`````````!@```!!<2```-````````2=``
M```````%E@!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?
M;6%I;@!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K
M7V-H:U]F86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P
M96YD:7(`<F5A9&1I<C8T`&-L;W-E9&ER`')M9&ER`%]?<W!R:6YT9E]C:&L`
M=6YL:6YK`%!,7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R
M;%]N97=84P!097)L7VYE=UA37V9L86=S`')E861L:6YK`%!E<FQ?<W9?<V5T
M<'8`;65M8VAR`%!E<FQ?<W9?<V5T<'9N`')E86QL;V,`7U]M96UM;W9E7V-H
M:P!G971P:60`7U]M96UC<'E?8VAK`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T
M<G)C:'(`;65M8W!Y`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS965K
M-C0`<F5A9`!G971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN
M=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD
M=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U
M8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O
M;G-T<G5C=`!P97)L7W)U;@!L:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`'!A
M<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?
M9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'-H85]U
M<&1A=&4`>'-?:6YI=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M
M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G
M`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,
M24)#7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,
M24)#7S(N,@````````(``0`"``(``0`!``(``0`!``(``P`"``(``0`"``$`
M`0`$``(``0`!``(``@`"``$`!0`!``(``0`!``(``0`!``$``@`"``(``@`!
M``(``@`&``$``0`&``(`!@`%``(``0`"``$``@`"``$``@`"``8``0`$``(`
M`0`'``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`&```"Z@```!``````!I:1M`````<```0D````
M$`UI:10````&```$+P```!`&EI&S````!0``!#D````0"6D9=`````0```1$
M````$`EI&7(````#```$4````!`-:6D2`````@``!%P`````````````N[@`
M````````#````````"0@````````N\``````````#````````"/0````````
MOZ@`````````#````````%SP````````O^@`````````#````````,"`````
M````O_@`````````#````````"!P````````P`@`````````#````````,`(
M````````P"``````````#````````*/P````````P"@`````````#```````
M`&/<````````P#@`````````#````````&1\````````P$``````````#```
M`````&2`````````P$@`````````#````````*/D````````P%``````````
M#````````&/B````````P%@`````````#````````*/L````````P&@`````
M````#````````*/4````````P'``````````#````````*/:````````P(``
M````````#````````&9D````````OY`````$````"@``````````````````
MOY@````)````"@``````````````````OZ`````*````"@``````````````
M````O[`````5````"@``````````````````O[@````:````"@``````````
M````````O\`````>````.```````````````````O\@````?````"@``````
M````````````O]`````A````"@``````````````````O]@````E````"@``
M````````````````O^`````X````"@``````````````````O_````!"````
M"@``````````````````O>`````"````"P``````````````````O>@````#
M````"P``````````````````O?`````%````"P``````````````````O?@`
M```&````"P``````````````````O@`````'````"P``````````````````
MO@@````(````"P``````````````````OA`````+````"P``````````````
M````OA@````,````"P``````````````````OB`````-````"P``````````
M````````OB@````.````"P``````````````````OC`````/````"P``````
M````````````OC@````0````"P``````````````````OD`````1````"P``
M````````````````OD@````2````"P``````````````````OE`````3````
M"P``````````````````OE@````4````"P``````````````````OF`````6
M````"P``````````````````OF@````7````"P``````````````````OG``
M```9````"P``````````````````OG@````;````"P``````````````````
MOH`````<````"P``````````````````OH@````=````"P``````````````
M````OI`````@````"P``````````````````OI@````B````"P``````````
M````````OJ`````C````"P``````````````````OJ@````D````"P``````
M````````````OK`````E````"P``````````````````OK@````F````"P``
M````````````````OL`````G````"P``````````````````OL@````H````
M"P``````````````````OM`````I````"P``````````````````OM@````J
M````"P``````````````````ON`````K````"P``````````````````ON@`
M```L````"P``````````````````OO`````M````"P``````````````````
MOO@````N````"P``````````````````OP`````O````"P``````````````
M````OP@````P````"P``````````````````OQ`````Q````"P``````````
M````````OQ@````R````"P``````````````````OR`````S````"P``````
M````````````OR@````T````"P``````````````````OS`````U````"P``
M````````````````OS@````V````"P``````````````````OT`````W````
M"P``````````````````OT@````Y````"P``````````````````OU`````Z
M````"P``````````````````OU@````[````"P``````````````````OV``
M```\````"P``````````````````OV@````]````"P``````````````````
MOW`````^````"P``````````````````OW@````_````"P``````````````
M````OX````!`````"P``````````````````OX@```!!````"P``````````
MZV_P,``DN00`'Z?[_V#C$/```"3`P```4C+`$```4QOC$!````2Y`@`1IX0`
M`PWAXT#Q$``$ZV_PT``$!_0``.,0\#@`),`0``!2&=('\#`0".,0$!``!`?Q
M!P`'``<`P!```%(8XQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```4@SC
M$!````0'\0T0XQ`0#``4P/3____5````&,`0``!2`.,0$```!`?Q#1#C$!`,
M`!3`]/___\4````PP!```%'TXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`
M$```4>CC$!````0'\0T0XQ`0#``4P/3___^E````8,`0``!1W.,0$```!`?Q
M#1#C$!`,`!3`]/___Y4```!XP!```%'0XQ`0```$!_$-$.,0$`P`%,#T____
MA0```)#`$```4<3C$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!1N.,0
M$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```%&LXQ`0```$!_$-$.,0$`P`
M%,#T____50```-C`$```4:#C$!````0'\0T0XQ`0#``4P/3___]%````\,`0
M``!1E.,0$```!`?Q#1#C$!`,`!3`]/___S4```$(P!```%&(XQ`0```$!_$-
M$.,0$`P`%,#T____)0```2#`$```47SC$!````0'\0T0XQ`0#``4P/3___\5
M```!.,`0``!1<.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```%%DXQ`0
M```$!_$-$.,0$`P`%,#T___^]0```6C`$```45CC$!````0'\0T0XQ`0#``4
MP/3___[E```!@,`0``!13.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!``
M`%%`XQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`$```433C$!````0'\0T0
MXQ`0#``4P/3___ZU```!R,`0``!1*.,0$```!`?Q#1#C$!`,`!3`]/___J4`
M``'@P!```%$<XQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```41#C$!``
M``0'\0T0XQ`0#``4P/3___Z%```"$,`0``!1!.,0$```!`?Q#1#C$!`,`!3`
M]/___G4```(HP!```%#XXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```
M4.SC$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0``!0X.,0$```!`?Q#1#C
M$!`,`!3`]/___D4```)PP!```%#4XQ`0```$!_$-$.,0$`P`%,#T___^-0``
M`HC`$```4,CC$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!0O.,0$```
M!`?Q#1#C$!`,`!3`]/___A4```*XP!```%"PXQ`0```$!_$-$.,0$`P`%,#T
M___^!0```M#`$```4*3C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!0
MF.,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!```%",XQ`0```$!_$-$.,0
M$`P`%,#T___]U0```QC`$```4(#C$!````0'\0T0XQ`0#``4P/3___W%```#
M,,`0``!0=.,0$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```%!HXQ`0```$
M!_$-$.,0$`P`%,#T___]I0```V#`$```4%SC$!````0'\0T0XQ`0#``4P/3_
M__V5```#>,`0``!04.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```%!$
MXQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```4#CC$!````0'\0T0XQ`0
M#``4P/3___UE```#P,`0``!0+.,0$```!`?Q#1#C$!`,`!3`]/___54```/8
MP!```%`@XQ`0```$!_$-$.,0$`P`%,#T___]10```_#`$```4!3C$!````0'
M\0T0XQ`0#``4P/3___TU```$",`0``!0".,0$```!`?Q#1#C$!`,`!3`]/__
M_24```0@P!```$_\XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```3_#C
M$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!/Y.,0$```!`?Q#1#C$!`,
M`!3`]/___/4```1HP!```$_8XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`
M$```3\SC$!````0'\0T0XQ`0#``4P/3___S5```$F,`0``!/P.,0$```!`?Q
M#1#C$!`,`!3`]/___,4```2PP!```$^TXQ`0```$!_$-$.,0$`P`%,#T___\
MM0``!,C`$```3ZCC$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!/G.,0
M$```!`?Q#1#C$!`,`!3`]/___)4```3XZV_P,``DLD\`L+D$`._KNP`@``VR
M3P"QX_#_./]QX^#P```DXS#PJ``DXT#PH``D4"#PM$%`\*!!,/"HT@?PP+`H
M02#PM,#E____K<1(``!/;L0H``!/A[D$`#3`Y0``(3K$&```3X>5`!``IX0`
MN<`P``!/<.-0,```!%B@\+3C9;````3LF@`$`-B6`V2*N10`Z>LN``,`#:>J
M``/`Y?___O'C$/"H``3`,```3[/C`!````3C8#````3C`"```"18D/"TN00`
M4N-@4!``),0K``!/K,!````BC>-`4!@`),`@```BA>,@4`@`).R<`,4!?NQ)
M``,`V.P)__\`V$'@$`BG*``$IP$``:=T`(*(```!N10`8NM&``,`#>-@X```
M!.P2``$`V.-D4```)+D4`#'K$P`#``WC,.`(``2G*@`"XS%0```DI^L`$*<&
M_^/LZ0`#`-C$*```3W"Y%`">N10`2NNI``,`#4'J4`#E2.````"G:0``P#``
M``X;P.7___P@["@`5`!^Q"@``$]606#PO,#E___]Y;D$`#:Y!`"2P"```"$-
MP.4```P[["@`1P!\Q"@``$]!P.7___O2P.7___S_U0?PP+`HIW0`6;D$`"GK
M;_#X``0'_L#E___\L<0K``!/*NPH`$X`?,#E___]*,`P``!.K>,@,```!.-"
ML```!)(`27ZG]/\UXS#@```$IR@`!>,P4"``)$'@$!#L)/]V8':G]/^4Q"@`
M`$\%P.7___PFI_3_J<!0``!.^>,@4````J>$``?`Y0``'D&G]/^QN00`-L`@
M```@B<#E```+W\0K``!.Y.PH_Z0`?*?T_^VGZ``$I_3_;L#E___]D*<I``'`
MY?___1M!0/`(XS#P```$IPG_\+F``/"G^_]0UP?P`/``Z^_PH``D07#PH*=I
M``"G60``P"```$YEXR`@```$P.7___Y[```'!P<'!P<'!P<'!P<'!\`0``!.
MG,`@``!.F>P2``J`9,08``!.)^P8``0`?`?Q!_X'!P<'!P<'!P<'!P<'!\`0
M``!.A,`@``!.@;D)`!+K`0`#``KK,0`_``RY"``PZS,``0`*[#@`#0!\Q!@`
M`$X&[!@`!P!\P"```$YH!_$'_@<'!P<'!P<'!P<'!P<'Z[_P6``DP+```$Y9
MX_#_8/]QE0"P`*=T`!7`$```3??C$!````*GA``(Q"@``$X'P.7___QXP.7_
M__^ED@&P`.N_\/@`!`?^!P<'!P<'!P?`]/___[`'!P<'!P<'!P<'ZV_P,``D
MLD\`L+D$`._C\/S0_W'CX/```"3KZP`@``VR3P#AYV`/#P!$0:#PJ-('\RC@
M*+D$`!I!4"`XN00`.J=)``3G`%``,`:G6P`0YR``(#`XYQ!@``!HYT(0`#!A
MYS(0`#!@YT`P`#`.YS`P$#`.ISL`(*='_^?GP*`0.`;GX*`@.`;G(*`P.`;G
M4`\/`$2G"0`@YP`0:#@&YW(```16YR`00#@&YT`0`#@&IQL`$.=B```.;><6
M0``.;><QP``.;>=3``$\,.=S`!\\..>%<``.:N>H4``,:.>@$'`X#N?.```,
M5N?G```(5J<'_]3CL"`(``3CH"`0``3CT"`8``3C4"````3CT/"@`"3C,/"H
M``2YY]!*N8``2[F"`$WL=2"_)5G".EJ">9GL=2`Z!5;C,"`@``CC@/"P``2Y
M"`!SXP#PN``$N0@`=.-`\,``!,**6H)YF<)*6H)YF;D(`(W""EJ">9FY"``*
MZVL``@`,ZS4``@`,[&L`(1Y6[#4`(1Y6[)8@OP!5N8(`8[GGD!JY@``5N8(`
M&KD(`!CLAR"_`%6Y@`!HN8(`:;D(`&"YZ)`$XT#PR``$[-<[OR59PDI:@GF9
M[-@`.@56N0@`'>QQ(+\`5>P1.[\E6>P7`#H%5KD(`!;KF``"``SL8R"_`%7L
MF``A'E;LT3N_)5GL@2"_`%6Y@@`YN>1P$[F"`!:Y"``0N>A@!.-`\-``!+D$
M`#W"2EJ">9GL.``Z!5:Y"``3[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@
MOP!5N8(`D^?0#P\(1+GD@!FY@@`6N0@`$+GH8`3C0/#8``2Y!`"=PDI:@GF9
M[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8`"$>5NR!(+\`5;F"`#FY
MY'`3N8(`%KD(`!"YZ&`$XT#PX``$N00`/<)*6H)YF>PX`#H%5KD(`!/L:2"_
M`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_`%6Y@@"3N>2`&;F"`!:Y"``0N>A@
M!.-`\.@`!+D$`)W"2EJ">9GLEP`Z!5:Y"``9[&,@OP!5[-$[OR59ZY@``@`,
M[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6N0@`$+GH8`3C0/#P``2Y!``]PDI:
M@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E6>LW``(`#.PW`"$>5NQQ(+\`5;F"
M`).YY(`9N8(`%KD(`!"YZ&`$XT#P^``$N00`G<)*6H)YF>R7`#H%5KD(`!GL
M8R"_`%7LT3N_)5GKF``"``SLF``A'E;L@2"_`%6Y@@`YN>1P$[F"`!:Y"``0
MN>A@!.-`\0``!+D$`#W"2EJ">9GL.``Z!5:Y"``3[&D@OP!5[-$[OR59ZS<`
M`@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY@@`6N0@`$+GH8`3C0/$(``2Y!`"=
MPDI:@GF9[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8`"$>5NR!(+\`
M5;F"`#FYY'`3N8(`%KD(`!"YZ&`$XT#Q$``$N00`/<)*6H)YF>PX`#H%5KD(
M`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_`%6Y@@"3N>2`&;F"`!:Y
M"``0N>A@!.-`\1@`!+D$`)W"2EJ">9GLEP`Z!5:Y"``9[&,@OP!5[-$[OR59
MZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6N0@`$+GH8`3C0/$@``2Y
M!``][#@`.@56[&D@OP!5N0@`$\)*6H)YF>LW``(`#.PW`"$>5KF"`)/L<2"_
M`%7LT3N_)5FYY(`9N00`G;F"`!;LEP`Z!5:Y"``0N>A@!.-`\2@`!+D(`!GL
M8R"_`%7KF``"``SLF``A'E:Y@@`Y[($@OP!5[-$[OR59PDI:@GF9N>1P$[D$
M`#WL.``Z!5:Y@@`6N0@`$+GH8`2Y"``3[&D@OP!5ZS<``@`,XT#Q,``$[#<`
M(1Y6N8(`D^QQ(+\`5>S1.[\E6;GD@!FY!`"=[)<`.@56N8(`%L)*6H)YF;D(
M`!"YZ&`$N0@`&>QC(+\`5>N8``(`#.R8`"$>5KF"`#GL@2"_`%7LT3N_)5GC
M0/$X``2YY'`3N00`/>PX`#H%5KF"`!:Y"``0N0@`$^LW``(`#.PW`"$>5N-P
M\4``!,)*6H)YF;GH8`3L:2"_`%7">EJ">9FY@@"3N>A@1[F``)CLT3N_)5FY
M@@"6[-$@.@56ZV@``@`,P!H`````[&@`(1Y6XX#Q2``$[',@OP!5N0@`D+F"
M`#:Y"`"=N8``,>P).[\E6;F"`#?L"2`Z!5:Y"``TZT$``@`,N0@`,.Q!`"$>
M5NP3.[\E6>P3(#H%5KGG0-;"BF[9ZZ&Y@@#9N0@`>+D:`'VY"`!QXQ#Q6``$
MXP#Q4``$[-DBOSY9PAINV>NA[-D"(1Y6N1H`%+GGT(3L0R*_/EFY@@"#[$,"
M(1Y6N>=`/;F"`#?""F[9ZZ&Y&@`3N1H`!N,P\6@`!+D$`)"Y&@"8XX#Q8``$
M[&<[OR59[&<@.@56N0@`EL**;MGKH>QI.[\E6;D:`(WL:2`Z!5;LUR*_/EFY
M"``6[-<"(1Y6PCINV>NAN>?0=+D:`#2Y@@!Y[$DBOSY9[$D"(1Y6N>=`G;F"
M`)'L`3N_)5FY&@`Y[`$@.@56XY#Q<``$N1H`A^QA(K\^6;D(`(#L80(A'E;L
M"#N_)5GC$/%X``3L""`Z!5:Y"``PPIINV>NAN>=@=,(:;MGKH;F"`'BY&@`4
M[$@BOSY9[$@"(1Y6XX#Q@``$N1H`G<**;MGKH;D:`)>Y&@"&N>=`=NS3.[\E
M6;F"`'/LTR`Z!5:Y&@`7N0@`G>QC(K\^6>P).[\E6>QC`B$>5NP)(#H%5KD(
M`!#L,3N_)5GL,2`Z!5:SP0!3XS#QB``$N>=@!,(Z;MGKH;F"``FY&@`T['DB
MOSY9L\T`1>QY`B$>5N.0\9``!+D:`(#"FF[9ZZ&Y"`"$N>=P!KD:`):Y@@`!
M[-@[OR59N1H`,.S8(#H%5NQA(K\^6;D(`#WL80(A'E;L$SN_)5GL$R`Z!5:Y
MYV#7XT#QF``$N8(`V+D:`)VY"`"1[!@BOSY9[!@"(1Y6XX#QH``$N><0UL)*
M;MGKH;F"`-.Y&@!'[`D[OR59N1H`3>P)(#H%5L**;MGKH;D(`$"Y&@"&[&,B
MOSY9[&,"(1Y6[#0[OR59[#0@.@56L\$`(^,P\:@`!+GG8`'".F[9ZZ&Y@@`)
MN1H`,>QY(K\^6;/-`!+L>0(A'E;CD/&P``2Y&@"`PIINV>NAN0@`@;GG<`:Y
M&@"6[-@[OR59[-@@.@56L\$`';/-`&&Y@@`$[-0BOSY9N1H`,.S4`B$>5KD(
M`#:YY]`'[$,[OR59N8(`".Q#(#H%5KD:`)"Y"`"4[&D[OR59[&D@.@56XQ#Q
MN``$L\$`-N-@\<``!+/-``/"&F[9ZZ'L2"*_/EFY&@`7[$@"(1Y6PFINV>NA
MN>=`C;D:`&VY@@"#[-,BOSY9N1H`&.S3`B$>5KD(`!#L,3N_)5GL,2`Z!5:S
MP0!3XS#QR``$N>?0=,(Z;MGKH;D:`#2SS0!%N8(`>>R)(K\^6;D:`&?LB0(A
M'E:Y"`!DN>>`G>P&.[\E6;F"`)'L!B`Z!5:Y&@`Y[$$BOSY9N0@`,.Q!`B$>
M5NP3.[\E6>P3(#H%5K/!`&'C$/'8``2YYT`(PAINV>NAXW#QT``$N1H`&+/-
M`(:Y@@`&PGINV>NAN1H`?;D:`'"Y"`!X[(<@OP!5[)<[OR59[)@`.@56[-8B
MOSY9XP#QZ``$[-8"(1Y6N>?09+F"`&.Y&@`6N0@`&>.0\>``!.QC(K\^6<*:
M;MGKH>QC`B$>5KD:`)2YYV`][$$[OR59N8(`-\(*CQN\W.QQ(+\`5;D:``WK
M&``"``SL&``A'E;LT2"_`%6YY-"&[$<`.@56N1H`D[GF$#:Y@``WN8$`...`
M\?``!+D(`)2Y"``P[$D@OP!5XP#Q^``$[)D[OR59[)0`.@56PHJ/&[S<N0@`
M.;D:`(;KEP`"``SLEP`A'E:YY-!YN8$`&;F``!2Y@0`7N0@`&.QC(+\`5<(*
MCQN\W.PS.[\E6;D(``WL-@`Z!5:Y"``QZQ0``@`,[!0`(1Y6[-$@OP!5N>30
MB;GF$$FY@`!&N8$`2.R#(+\`5;D(`$#C`/(```3L,SN_)5GL.``Z!5:Y"``T
M[',@OP!5[$,[OR59XS#R"``$P@J/&[S<N1H`">N6``(`#.R6`"$>5KGDT&FY
M@0`9N8``&+F!`!:Y"``0[$<`.@56PCJ/&[S<N0@`0;GHT`/K&``"``SL&``A
M'E;LT2"_`%6YY-")N>80:;F``&>Y@0!H[(0@OP!5N0@`8.Q$.[\E6>,`\A``
M!.Q(`#H%5KD(`$;L9""_`%7L-#N_)5GC0/(8``3""H\;O-RY&@`)PDJ/&[S<
MZY<``@`,[)<`(1Y6N>30>;F!`!FY@``8N8$`%[D(`!"YZ-`$[#8`.@56N0@`
M,>L8``(`#.P8`"$>5NS1(+\`5;GF$(FYY-!YN8``AKF!`(?C</(H``2Y"`"`
MXP#R(``$[$,@OP!5P@J/&[S<N1H`"<)ZCQN\W.PS.[\E6>PT`#H%5KD(`#CK
MA@`"``SLA@`A'E:YY-!HN8$`&+F``!2Y@0`6N0@`$+GHT`?LDR"_`%7L,SN_
M)5GL.0`Z!5:Y"``QZQ0``@`,[',@OP!5[!0`(1Y6[#,[OR59[-$@OP!5N>80
M2+GDT&BY@`!)[#<`.@56N8$`1KD(`$#C`/(P``2Y"``T[$,@OP!5[&,[OR59
MXS#R.``$P@J/&[S<N1H`".N)``(`#.R)`"$>5KGF@)&YY-`8[&0`.@56N8``
ME\(ZCQN\W+F!`)&Y"``]L\$`([D(`)"SS0`"N0@`ENL7``(`#.P7`"$>5NS1
M(+\`5;GDT'BYYA`X[&D[OR59N8``-+F!`#?L>2"_`%7CD/)```3L9P`Z!5:Y
M"``PPIJ/&[S<N0@`-K/!`!FSS0!AZY0``@`,N1H`:.R4`"$>5NQ#(+\`5;GD
MT`FY@0`9N8``%[F!`!"Y"``6XV#R2``$[#,[OR59PFJ/&[S<N>C0!NPT`#H%
M5KD(`#'K%P`"``SL%P`A'E;LT2"_`%6YYA!YN>30B;F``'2Y@0!XN0@`<.,`
M\E``!.R#(+\`5<(*CQN\W.PS.[\E6;D:``GL.``Z!5:YZ#"7ZS0``@`,['D@
MOP!5[#0`(1Y6[$D[OR59XY#R6``$N>308[F!`!/"FH\;O-RY@``8N8$`%KD(
M`!"YZ-`)[$<`.@56N0@`0>L8``(`#.P8`"$>5NS1(+\`5;GF$&.YY-"#N8``
M9[F!`&BY"`!@XP#R8``$[(0@OP!5P@J/&[S<[$0[OR59N1H``^Q(`#H%5KGH
M0#;L8R"_`%7L0SN_)5GC,/)H``3KEP`"``S".H\;O-SLEP`A'E:YY-!YN8$`
M&;F``!BY@0`7N0@`$+GHT`/C,/)P``3L1@`Z!5:Y"`!!ZQ@``@`,[!@`(1Y6
M['$@OP!5N>1PB;GF$-G".H\;O-RY@`#6N1H`.;F!`-CKE@`"``SLA""_`%7L
ME@`A'E:Y"`#0[$0[OR59[$@`.@56N0@`3>QD.[\E6>S4(+\`5;GFD$&Y!``6
MXV#R>``$N>1P">P=`#H%5KF``$C":H\;O-RY@0!`N0@`0[GH<#:Y"`!!ZQ@`
M`@`,[!@`(1Y6['$@OP!5N>80B;GD<&FY@`"-N8$`AKD(`(/C,/*```3L!#N_
M)5G".H\;O-SL!"`Z!5:Y&@`YL\$``[D(`(#K;0`"``SC,/*(``2Y!`"6[)T`
M(1Y6N>1P";/-`&#`2@````"Y@0`9N8``%+F!`!#C`/*0``3".LIBP=:YZ'!S
MN0@`%NS8.[\E6;/!`"?LV"`Z!5;K=``"``S""LIBP=;L=``A'E:Y&@`)N>=P
M2;/!`$"Y@@!([&@BOSY9L\T`,NQH`B$>5K/-`(2Y"``=[-$[OR59[-$@.@56
MN1H`-+D(`#VYYV#7[$,[OR59N8(`T>Q#(#H%5KD:`(VY"`"$[)@[OR59[)@@
M.@56XP#RF``$L\$`6>.0\J``!+/-`-7""LIBP=;"FLIBP=:Y&@`'N1H`ENQQ
M(K\^6>QQ`B$>5KD$`!"YYW!&[&,BOSY9N8(`0^QC`B$>5KD:`!2Y"``=[#$[
MOR59[#$@.@56N>=@!^-`\J@`!+F"``BY&@"0N0@`D^PX(K\^6>PX`B$>5N.`
M\K``!+GG,`;"2LIBP=:Y@@`!N1H`1^S9.[\E6;D:`$#LV2`Z!5;"BLIBP=:Y
M"`!-N1H`ANQA(K\^6>QA`B$>5NP4.[\E6>P4(#H%5K/!``'C$/*X``2YYV#3
MPAK*8L'6N8(`V;D:`!/L>2*_/EFSS0`P['D"(1Y6XY#RP``$N1H`C<*:RF+!
MUKD(`(.YYW#6N1H`EKF"`-3C,/+(``2Y&@`=[`@[OR59[&0BOSY9[`@@.@56
M[&0"(1Y6N0@`$.Q!.[\E6>Q!(#H%5KGG8`>Y@@`(N1H`D+D(`)3L2"*_/EGL
M2`(A'E;C@/+0``2YYT`&PCK*8L'6N8(``;D:`#?LV3N_)5FY&@`P[-D@.@56
MPHK*8L'6N0@`/;D:`(;L82*_/EGL80(A'E;L$SN_)5GL$R`Z!5:SP0`QXQ#R
MV``$N>=@U,(:RF+!UKF"`-FY&@`4['DBOSY9L\T`0^QY`B$>5N.0\N``!+D:
M`(W"FLIBP=:Y"`"$N>=PUKD:`):Y@@#3[`@[OR59N1H`'>P((#H%5NQC(K\^
M6;D(`!#L8P(A'E;L,3N_)5GL,2`Z!5:YYV`'XT#RZ``$N8(`"+D:`)"Y"`"3
M[#@BOSY9[#@"(1Y6XX#R\``$N><P!L)*RF+!UKF"``&Y&@!'[-D[OR59N1H`
M0.S9(#H%5L**RF+!UKD(`$VY&@"&[&$BOSY9[&$"(1Y6[!0[OR59[!0@.@56
ML\$``>,0\O@`!+GG8-/"&LIBP=:Y&@`3L\T`,+F"`-GL>2*_/EFY&@"-['D"
M(1Y6N0@`@^.0\P``!.,P\P@`!.P(.[\E6>P((#H%5KGG<-;"FLIBP=:Y@@#4
MN1H`EKD:`!WL9"*_/EFY"``0[&0"(1Y6PCK*8L'6N>=@![D:`#?C</,0``3L
M03N_)5GL02`Z!5:Y@@`([-@BOSY9N1H`D.S8`B$>5KD(`)2YY]"&[$D[OR59
MN8(`@>Q)(#H%5KD:`#C">LIBP=:Y"``TN1H`=NQA(K\^6>QA`B$>5NP3.[\E
M6>P3(#H%5K/!`#'C$/,8``2YYV!-[(DBOSY9N8(`2>R)`B$>5KGG@):Y@@"3
MPAK*8L'6N1H`';/-`-.Y&@`9[),BOSY9[),"(1Y6XS#S(``$N1H`=,(ZRF+!
MUKD(`'VYYY!([-<@OP!5N0@`->P'.[\E6;D:`#;L#0`Z!5:Y!`!4N0@`$+F"
M`%?L82"_`%6Y!`!S[!$[OR59N1H`=>P6`#H%5KD(`!>Y"`!KXY#PH``(YY%@
M``ABZ[T``@`,Y_G0``YHY_`@`#@.[+T`(1Y6N>B@J^>ZD``(8N.`("``".<+
MT``.:.<`(!`X#L"*`````..`("``)-4'\RC@**=T``;K;_-@``0'_L#E___Q
MQ@<'!P<'!^MO\#``)+D$`._C\/]@_W'CX/```"3L*`!<`'S$&```0G+C<!``
M``*GA`!3XP`@``"4N00`@KD$`&.Y!`"2E0`@`*>$`$[L"``,/7Y!D)`!XP"0
M``"4E0"0`*=T__8;F..@<````J>$`!^Y%`"9N00`M[D$`$FY!``XN00`*L#E
M___P0>PF``D`?D$IH`"5/2``IX0`#T&PL`CCH+````*G=/_IN00`*NMO\-``
M!`?^N>EP.T&IH`'K0P`#``I00&``N00`*NMO\-``!`?^IZD``+D$`"KK;_#0
M``0'_J>8``"G]/^_!P<'!P<'!P<'!^NO\%``)+)/`+"Y!`#OZ[L`(``-LD\`
ML>/P_LC_<>/@\```)+D$`*)!,/"@T@?Q,+`HP.7___%?["8`(0!^&!)8(/"X
MISA``,`K``#P`.PC``B`=J4/H`#L(``38':Y!``JISD``L#E___QQ1`2IQK_
M_X@0`!^G]``$IQ@``-4'\3"P*+D4`"&G=``&ZZ_QB``$!_[`Y?__\/X'!P<'
M!P?K;_`P`"2R3P"@N00`[^NJ`"``#;)/`*'C\/[`_W'CX/```"32!_$XH"CL
M*``)`'RY!`!BE0`@`*=T``O5!_$XH"BG=`"'ZV_Q<``$!_[`Y?__\<&Y!`"2
M["C_\@!\N00`*<#E___P)^PH`%H`?$&P(!.5+B`3IW0`!I4`L`&GA/_PE2X@
M$Z>$`%>G&0``[$8\OP!5IX0`6J<Y``^Y"0`TYP-@```WIQL`$.<@`#``@:>$
M``SG`6``0`:G&P`0YR``,`"!IW3_^.<"``<`(4%0,`&YA`"`N2``@[GB(!6G
M)``UX^&/\/]Q[$L\OP!5IQD``*>$`#*G.0`/N0D`-.=#(!,`-Z<;`!#G9$`P
M`(&GA``HYT$@$T`&I_3_]KD$`"G`Y?__[HBY!``FP.7__^[#I_3_AI4NL`&G
M=/^IE0"P`J>$_X^G]/^CISD`#Z?T_[3`Y?__\%"G.0`/I_3_W.<&``<`(4%0
M,`&YA`"`N2``@[GB(!6G)/_QXR&/\/]Q&N*GZ@`"N10`CKD$`"C`Y?__[F+C
ML/"@`"2G.0`"N00`LKD$`$C`4```$N#`Y?__\..Y!``K03#PJ,#E___O'.PH
M``W_?EC@\,"G&$``P.L``/``[.$`#X!VN00`*\#E___P2KD$`"O`Y?__\(6G
M]/\YN00`*\#E____!J?T__0'!^MO\#``)+)/`*#`$```0,OK:@`@``WCL!``
M``2R3P!AN00`[^/P_UC_<>/@\```).,K8```!,1(``!`N<!0```RZL`P```2
ME,#E___PI.5(\*```.,K8```!,!````/.\!@```3[<`P```2D+D$`%;`Y?__
M[P#K;_#8``0'_@<'ZW_P.``DLD\`L+D$`._KNP`@``VR3P"QX_#_6/YQX^#P
M```DXQ#PH`%QN00`@]('$`"P*$&0\*"Y!`"BN00`.:=)#__`(```$FS`Y?__
M[G/L+``2`'[L`O__`-@8$KD4`"!!,O"@E0`P`*=T`"+L!@`?`'[`0```0%;C
M4$````2Y!``ZXR6P```$N00`2,#E___N$>.0\*`!<=4'D`"P**=T`"GK?_#@
M`00'_A@0N10`<;D$`"FY!`!'ISD`+\#E___N2>PH_]@`?,#@``!`*^.`X```
M!+D$`%?C*+````2Y!`!)N00`.L#E___NY*?T_]/`Y?__[S\'!P<'!P<'!^MO
M\#``)+)/`'"Y!`#OZW<`(``-LD\`<>/P_T#_<>/@\```)+D$`+*Y!`"CT@?P
MN'`HE3TP`*=T``1!H#`!IQD``.PZ/+\`5:>$`'FG*0`/N0D`(^<"H```-Z<;
M`!#G(``P`(&GA``,YP&@`$`&IQL`$.<@`#``@:=T__CG`@`'`"%!0"`!N80`
M4+D@`%*YXB`4IR0`5.-A7_#_<;D$`"OC8/"@`"1!,/"TP.7___TCN00`@NPH
M`$L`?*=I``#L,CR_`%6GA``_IRD`#[D)`"/G0H```#>G:P`0YV1`,`"!IX0`
M#.=&@`!`!J=K`!#G9$`P`(&G=/_XYT8`!P`A0=`@`;F$`%2Y(`!2N>(@;:<D
M`!KCD/"@``3C!E_P_W'LD`$(P&7C@/"T`!3$:```/V/KB``#``VG]`!8IRD`
M#Z?T_Y6G*0`/I_3_S\1H```_4^.`8```!.,0@````J>$`-^Y!`#HIY@``!C9
MIYH``4'@X`CC,.````*G=/_XI]H``[D4`!WK,0`#``WC,/"H`"3`(```/[#C
M$"```!*GA`"6XS#PJ``$N00`*,#E___M@^,@8```)+D$`-+L*`!Z`'RY%`!9
MZX4``P`-4)#PM*>:``&Y%`"9Z^D``P`-01[0`.5($````.,0L```E+D$`.N5
M`+``IW0`#:?T`(U!X.`!XQ#@``"4E0#@`*>$``7L%O_W/7ZY"0#KN10`/N,@
M\*``!+D$`-A!(C`"X]!@```(P.7__^Q0XR#0```D["@`.0!\XT!@```$XU"P
M``"0XYA````$06"P`4)0D``8A>Q6`!``?*?T`"[C`&```)!!8&`!0@"P`1B`
M[`@`)`!\0H#PH+D$`+F5/?"@09"0`:=T_^V2/;``I^D``.,>H```D$(>L`&G
MZP`![!;_^0!\U0?PN'`HIW0`.NMO\/``!`?^N00`N:?T_^?C(/"H``3`0```
M/Q'E3$````'`Y?__Z_NY!`#2["C_Y0!\XU#PJ``$N10`";D$`#CK@``#``VY
M!`!(P.7__^Z7X]!@```DI_3_7J<Y``"G]/^#Y4CPJ``0IY@``*?T_S;`Y?__
M[:2G.0``XR.@``"00B.``*<[``'L)O_Y`'RG]/^T!P<'!P<'LD\`(,`0```^
M9NM2`"``#>,P$```!+)/`%'$2```/E_C(U````3`4```,(W`,```$#?`]/__
M[D<'!P<'!P<'!^MO\#``)+)/`)"Y!`#OZYD`(``-LD\`D>/P_TC]<>/@\```
M).,0\+`"<>.P\*\!<=('$`"0*,#E___M%<`````0-N,`\*``)+D$`&*G21`!
MISD``KD$`"O`4```$")!@/"NP.7__^W_N00`*[D$`#BG21``P.7__^P6["0`
M,0!^['(``0#8N00`8KD4`'>Y!``GP.7__^M7N00`HNPH`!(`?+D4`+:Y!`!7
MN00`.+D$`$O`Y?__Z\=!*Z``D@`@`.,P\+`"<=4',`"0**=T``RY!``JZV_P
MZ`($!_ZGJ0``I_3_\,#E___L_@<'!P<'!\#T____B`<'!P<'!P<'!P?K;_`P
M`"2R3P#0N00`[^O=`"``#;)/`-'C\/ZP_G'CX/```"3C$/%(`7&Y!`"BT@<0
M`-`HN00`D\`@```/NT$P\+3`Y?__^P^G.0`ON00`LKD$`"K`Y?__[-;L*``9
M`'S`(```#ZRY!``ZP.7___V#N00`*N-P\4@!<=4'<`#0**=T`9CK;_&``00'
M_KD$`"G`Y?__Z]C`,```#YC`Y?__ZR*Y!`!B["C_W0!\[(H\OP!509#Q2$%P
M\+B5`&``IX0`MNRX``\`?*<(``"Y!``VN00`*[)=`#*G%/_^IX0`EJ=9``#L
M!CR_`%6GA`$FI^D`#[D)`.#G#F```#>G6P`0YR``,`"!IX0`#.<%8`!`!J=;
M`!#G(``P`(&G=/_XYQ(`!P`A04#@`;F$`#&Y(``^N>(@5*<D`0'C-3_P_W'C
MXV___W'L;@!_H&6YZ6`NIR$``:>$``Z5+^``IW0`\I(`X`#CX.___W'L;@`9
M@&3K4@`!``R5+^``IW0`XY(`X`#K+^___U6G=`#<ZP#O__]2X^#O_O]QIU?_
M[Z=I``#L7CR_`%6GA`$"IQD`#[D)`!7G$>```#>G:P`0YS$0,`"!IX0`#.<6
MX`!`!J=K`!#G,1`P`(&G=/_XYP,`!P`A03`0`;F$`$"Y(`!!N>(@8Z<D`-WC
M-D_P_W&Y!`!NI_0`(Y4`L`&G=``:P#````[?IRD``,#E___J9[D$`&+L*/\B
M`'R5`&``IW3_3NRX``<`?)4NL`"GA/_FISD``<!@```.N*?I``#LB`!T`'RG
M*0`/N0D`*.=2H```-Z?K`!#G=5`P`(&GA``,YUZ@`$`&I^L`$.=U4#``@:=T
M__CG%P`'`"%!4"`!N80`0;D@`$*YXB#EIR0`3N/N3_#_<4$.,`&G.0__[`/^
MWB!EXZ#PJ``DP!````Z,XQ#PH``DISD``KD$`"G`4```#OFG21``P.7__^Q)
MN00`-[D$`"G`Y?__ZH+L)O^3`'Y88/#0I2^``,!K``#P`.QB_XE@=KD$`"FG
M.0`!P.7__^P>[";_?P!^N00`.<`@```.4L#E___\*[D$`"G`Y?__ZHZG]/ZE
MIRD`#Z?T_YNGZ0`/I_3^Z*?I``#L!CR_`%6GA``LIQD`#[D)`!#G06```#>G
MZP`0YV1`,`"!IX0`#.=.8`!`!J?K`!#G9$`P`(&G=/_XYS8`!P`A04`0`;F$
M`".Y(``AN>(@Y*<D``?C/B_P_W&G]/]3IQD`#Z?T_^*G&0`/I_3_#,#E___K
M&`<'!P<'!P<'!P?KO_!8`"2Y!`#OX_#_8/]QX^#P```DN00`LJ<Y`"_`Y?__
MZZ'L*``%`'Q!L"`!N00`*^N_\/@`!,#T___J)`<'ZY_P2``DLD\`H+D$`._K
MJ@`@``VR3P"AX_#_6/YQX^#P```DXQ#PH`%QT@<0`*`H["@`F0!\N00`,I4`
M(`"GA`"2IYD``.Q"/+\`5:>$`(>G*0`/N0D`).<",```-Z>;`!#G(``P`(&G
MA``,YPDP`$`&IYL`$.<@`#``@:=T__CG`@`'`"%!4"`!N80`L+D@`+*YXB"5
MIR0`8N.9O_#_<:?I$`#L20`!`-GL3@!M(&5!L/"@N00`*\#E___KM.,9O___
M<>P;`"O`9;GIL#&G$0`!IX0`#I4O$`"G=``@D@`0`.,0'___<>P;`!F`9.M#
M``$`#)4O$`"G=``1D@`0`.LO'___5:=T``KK`!___U+C$!_^_W&G1__ON00`
M*Z<Y`"_`Y?__ZO_L*``=`'SL*P`%P&62`"``N00`*\#E___I@N-0\*`!<=4'
M4`"@**=T`!_KG_#P`00'_J<I``^G]/^'XR#PH`%QU0<@`*`HIW0`#\`@```-
M'>N?\/`!!,#T___I8:<I``"G]/_=P.7__^HJ!P<'!P<'!P<'!P<'!P?KK_!0
M`"2R3P"@N00`[^NJ`"``#;)/`*'C\/]0_W'CX/```"1!L/"DT@?PJ*`HN00`
M.\`@```,_,#E___X1.PH`"X`?,1(```ZON,@\*0`%.L2``,`#>,00```".-0
M$`@`!.-0$```).Q8_^,`?.,`$!``!$$0$`CC`!```"3L!O_X`'RY!``[P"``
M``S1P.7___@9[";_V`!\N00`.\`@```,R\#E___X#NPH`"X`?,18```ZB.,0
M\*0`%.OA``,`#>/@4```".,`X`@`!.,`X```).P(_^,`?.,PX!``!$'@X`CC
M,.```"3L-O_X`'RY!``[P"````R@P.7___?C[";_V`!\N00`.\`@```,F<#E
M___WV.PH`"X`?,18```Z4N/@\*0`%.M.``,`#>-`4```".,P0`@`!.,P0```
M).PX_^,`?.,@0!``!$%`0`CC($```"3L)O_X`'RY!``[P"````QNP.7___>M
M[";_V`!\N00`.\`@```,:,#E___WHNPH`"X`?,0X```Z'.,@\*0`%.L2``,`
M#>,0,```".-`$`@`!.-`$```).Q(_^,`?.,`$!``!$$0$`CC`!```"3L!O_X
M`'RY!``[P"````P]P.7___=W[";_V`!\N00`.\`@```,-L#E___W;.PH`"X`
M?,1(```YYN,0\*0`%.M1``,`#>-00```".,`4`@`!.,`4```).P(_^,`?./@
M4!``!$%04`CCX%```"3LYO_X`'RY!``[P"````P+P.7___=![";_V`!\N00`
M.\`@```,",#E___W-NPH`"X`?,1(```YL.-0\*0`%.LU``,`#>,P0```"./@
M,`@`!./@,```).SH_^,`?.,@,!``!$$P,`CC(#```"3L)O_X`'RY!``[P"``
M``O=P.7___<+[";_V`!\N00`.\`@```+JL#E___W`.PH`"X`?,3H```Y>N,@
M\*0`%.L2``,`#>,0X```".,P$`@`!.,P$```).PX_^,`?.,`$!``!$$0$`CC
M`!```"3L!O_X`'RY!``[P"````M_P.7___;5[";_V`!\N00`.\`@```+HL#E
M___VRNPH`"X`?,0X```Y1.,0\*0`%.M!``,`#>-`,```".,`0`@`!.,`0```
M).P(_^,`?.-00!``!$%`0`CC4$```"3L5O_X`'RY!``[P"````MWP.7___:?
M[";_V`!\N00`.\`@```+<<#E___VE.PH`"X`?,0X```Y#N-`\*0`%.OD``,`
M#>/@,```".-0X`@`!.-0X```).Q8_^,`?.,@X!``!$'@X`CC(.```"3L)O_X
M`'RY!``[P"````M&P.7___9I[";_V`!\N00`.\`@```+0,#E___V7NPH`"X`
M?,18```XV./@\*0`%.L>``,`#>,04```".,@$`@`!.,@$```).PH_^,`?.,`
M$!``!$$0$`CC`!```"3L!O_X`'RY!``[P"````L5P.7___8S[";_V`!\N00`
M.\`@```*U\#E___V*.PH`"X`?,0H```XHN,0\*0`%.LQ``,`#>,P(```".,`
M,`@`!.,`,```).P(_^,`?.-`,!``!$$P,`CC0#```"3L1O_X`'RY!``[P"``
M``JLP.7___7][";_V`!\N00`.\`@```*V<#E___U\KD$`#+L*``)`'S`(```
M"L3`Y?__^&^Y!``[P"````K/P.7___7?N00`,NPH``D`?,`@```*S<#E___X
M7+D$`#O`(```"LO`Y?__]<RY!``R["@`&@!\P"````IKP.7___A)U0?PJ*`H
MIW0`(\`P```*QL`@```*?>NO\0``!,#T___X.+D$`#O`(```"J_`Y?__]:BY
M!``R["C_Y0!\P"````IUP.7___@EI_3_W,#E___G6`<'!P<'!P<'!P?KO_!8
M`"2R3P"PN00`[^N[`"``#;)/`+'C\/]0_W'CX/```"1!,/"DP"````I1T@?P
MJ+`HP.7___5V["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`$.PQ/[\!6=4'
M\*BP*+D4`".G=``*Z[_Q"``$!_ZG.```I_3_\\#E___G$V``\(!@(/"(8$#P
MD&!@\)CK/_`8`"3$&```-_6R3P``N00`[^/P_SC_<>/@\```)+D$`$+K,``@
M``WC(!````2R3P`Q0>#PR-('\,`P*./@\+@`).5(\*```>5(\*@``$%0\*!!
M8/%HXV#PL``DISD``L#E___FIZ<I`/_`Y?__YF('!P<'!P<'!P<'!P<'!^M_
M\#@`)+)/`)"Y!`#OZYD`(``-LD\`D>/P_U#O<>/@\```).,0\*@0<;D$`'+2
M!Q``D"BG20`"ISD``,#E___D^NR"__\`V>P(,(``5>R*``P`?*<+___`(?__
M``"Y@0`"IPL``;D)`(#LA`",`'Q!H/"@P+```#>.N00`.+D$`">G20``P.7_
M_^35["@`E?]\N00`.KD$`"?`00`!``C`Y?__YMCL*`""_WZY%``R[#P`8`=]
MXQ.O^/]Q[!H`6D!E[$$^OP!5U0<0`+``IX0`:.,0'___<>P:`$Q`9>Q(`"0`
M?.Q(`!8!?.Q(``L"?-4'$`"P`*>$`%3C$!___W'5!Q``L`"GA`!,XQ`?__]Q
MU0<0`+``IX0`1.,0'___<>P:`"A`9=4'$`"P`*>$`#GC4!___W&Y!``5U0=0
M`+``IX0`+^,07___<=4'$`"P`*>$`"?C$%_^_W'5!Q``L`"GA``?XQ!?_?]Q
M[!K_WJ!EPH0``0``P`'__P``[(#_?V!DIRG__^-P\*@0<=4'<`"0**=T`!CK
M?_#H$`0'_KGIH"&Y"``HI_3_\,`@```)2,#E___^X,`@```).\#E___^VL#E
M___EYP<'!P<'!P<'Z^_P<``DN00`[^/P_V#_<>/@\```),#E___CQ<#E___C
MHNPH``8`?.,@(```!.OO\1``!`?^!P<'!P<'!P<'!^MO\#``)+)/`*"Y!`#O
MZZH`(``-LD\`H>/P_T#_<>/@\```)+D$`&)!,/"TT@?PN*`HP"````D"P.7_
M__/D["@`"0!\N00`LI4`(`"G=``2U0?PN*`HIW0`6KD$`#;`(```".SK;_#P
M``3`]/__]E.G&0``[#8\OP!5IX0`1*<I``^Y"0`CYP)@```WIQL`$.<@`#``
M@:>$``SG`6``0`:G&P`0YR``,`"!IW3_^.<"``<`(4%`(`&YA`!0N2``4KGB
M(!2G)``?XY%?\/]QI^D``.P;/+\`5:>$`!RG*0`/N0D`(>="L```-Z?K`!#G
M9$`P`(&GA``2YTZP`$`&I_3_]J<I``^G]/_*P.7__^4[IRD`#Z?T__+G-@`'
M`"%!`"`!N80`0[D@`$*YXB#@IR3_\>->3_#_<4&94`*Y!``IP.7__^-0X[#P
MJ``DP+````@-X[#PH``DN00`2<!0```(?;D$`)*G.0`"P.7__^7+U0?PN*`H
MIW3_RKD$`#G`(```"%SK;_#P``3`]/__]</K;_`P`"2R3P`0N00`[^/P_BC_
M<>/@\```)*?K__A@@.``ZS$`(``-LD\`,<!````UXN,P\,``)-('\<@P*$&`
M\,RY!`#2N00`.-)'\/!`$-(/\-A`6-('\.A`:,`@```'L<#E___S!^PH``D`
M?+D$`+*5`"``IW0!?\#E___BJ\#E___BB.PH`#@`?..@(````J>$`#*GZ0``
M[`H\OP!5IX0`)Z<I``^Y"0`@YP*@```WI^L`$.<@`#``@:>$``SG#J``0`:G
MZP`0YR``,`"!IW3_^.=2``<`(4%@(`&YA`!UN2``<KGB(.:GQ`$EIRD`#Z?T
M_^=!</#8XR!P```"IX0`%;D$`#C`Y?__\K3L*``'`'R5`"``IW0`VJ=[``CC
M('````*G=/_OIRD`#:=Y``W`Y?__XH^GN0`-N00`DK/!`(+`H```![FG&`!3
MN00`2[D$`"FYA`!AISD``L!0```'L,#E___E!KDA`'NY!``[N>*@-[GIL!.G
M&P`"N2$`$[GB4!.Y"0"S0:"@`>.['_[_<4&0D`+C$*```)25`*``IW3_UD&0
M\1#`(```!UFG]``)IYL`".,@G_C_`J>$`""Y!``XP.7___)5N00`HNPH__(`
M?)4`(`"GA/_MP.7___+!["C_Z`!^N00`*L#E___C,;D$`&+L)@`=`'Q!</#P
MXV!P```"IX0`%94`8`"GA`#>N00`)L#E___RI.PF`,``?J=[``CC8'````*G
M=/_OI^D``.Q&/+\`5:>$`,2G*0`/N0D`).<28```-Z?K`!#G,1`P`(&GA``,
MYQY@`$`&I^L`$.<Q$#``@:=T__CG`P`'`"%!4"`!N80`,+D@`#*YXB#EIR0`
MG[/-`)CCOC_P_W&G&0``[*D\OP!5IX0##J?I``^Y"0#JYUZ0```WIQL`$.=U
M4#``@:>$`)2SS0!(YU%``$`&I_3_],#E___BPKD$`*+L*/\C`'RGZ0``[$(\
MOP!5IX0`0Z<I``^Y"0`DYT*@```WI^L`$.=D0#``@:>$``SG3J``0`:GZP`0
MYV1`,`"!IW3_^.<&``<`(4%0(`&YA`!PN2``<KGB(.6G)``>XVY_\/]QZ[8`
M`0`-I[L``;D$`"O`Y?__X83C$*```)2Y!`"2E0"@`*>$`#RY!`![L\$`@J?T
M_O.G*0`/I_3_R\#E___]?N-`\,``!-4'\<A`**=T`"MH@/'0N00`*^MO\@@`
M!,#T___B7+D$`":G>P`(P.7__^)5N00`8NPH_RD`?*?I``#L1CR_`%6G=/]`
MIRD`#Z?T_TJG:0``I_3_,;/!`(*G]/[GP.7__^,*YR<`!P`A00#@`;F$`%*Y
M(`!>N>(@$*<D`F'C,5_P_W$:.Z<Z!`2Y%`!SN00`)\#E___A(&"`\+#`$```
M!=_C$/"@`"3`L```!E3CL/"H`"2Y!`"2ISD``KD$`$?`4```!D/`Y?__XY:Y
M!``IISD!P,#E___B?^PF``O_?L#E___B25A@(`#L9@%<$7Y!H/$XL\$`BKD$
M`#JY!``IP.7__^+I&*+L)@`-`'Y8X/%0ITA``,#K``#P`.SD`"B`=L2(```S
MF.-0T```!.,@@```!+D$`&G`0```!BVG.0`"P.7__^*XI[D``.-0\,``!-4'
M\<A0**=T_X.Y!``K:(#QT.MO\@@`!`?^6+#Q5,#E___@<>RR_]9@=E@`\5"G
M*`'`P`L```'_[`+_S&!VN00`)\#E___@G[D$`#BY!`"RP"````8BP.7___"E
MN00`,NPH`.H`?.,@T```!,#E___U:KD$`&+L*`#?`'RG60``[#8\OP!5IX0`
MX:<9``^Y"0`3YP%@``@WIUL`$.<@`#`.@:>$``SG!6``2`:G6P`0YR``,`Z!
MIW3_^.?B``<$(4%`$`&YA``NN2``(;GB(%2G)`"\XU4O\/]Q[%P`(`-^N10`
M%<`P```%V^/A;_S_<:<(``"R70`^IQ3__J=T``_L6`$J!'ZG6O_[N10`14$D
M8`"5+R``IX0!'[D$`#C`(```!1;`Y?__\#[L*`"M`'SC@"```)3LB`"G`'[L
MB`"D,'[`,```!3S`(```!0'`Y?__\K'`Y?__X:;C(/"H`"3`````!@7C`/"P
M`"3`4```!,[C4/"@`"2Y!`!IN00`1[D$`"O`4```!9^G.0`"P.7__^*)I_0`
M,L#E___A1%A`(`"G3@`1IW0`,\#E___A>^,@\*@`),`P```%VN,P\+@`)*>J
M``'`@```!*'C@/"@`"2Y%``:XQ#PL``DN00`:;D$`$>Y!``KP%````5TISD`
M`L#E___B5[D$`"NG.0'`P.7__^%`["C_R?]^N00`*<#E___B"+D$`#O`(```
M!&K`Y?__\DBY!``KP.7___N[I_3^Y>-@T```!*=9``#L-CR_`%6G=/\CIQD`
M#Z?T_RW$*```,EBY%`!FXV#PH``DXU#0```$XR`@```$N00`:<!````$RJ<Y
M``+`Y?__X7.G]/Z[N00`)J<Y``#`Y?__X=JY!`#2["C_5@!^P.7___IZN00`
M8NPD_TX`?*=)``#C,&_V_W&Y!``MP.7__]^#N00`+4$P\-*G20`&P.7__^&*
M["8`D`9\P.```"0YU07@`/#2IW3_+^,P;\[_<:=)``"Y!``MP.7__]]EL\T`
M.+D$`"VG20`HP.7__^%L["8`<BA\8(#PJ)(`\6#`T```!2?CT/"P`"3`X```
M`_#CX/"@`"2Y!`!'N00`:;D$`"O`4```!+FG.0`"P.7__^&KI_3_7N/0T`@`
M`J>$_N"G&0``[`T\OP!5IX0`/:<Y``^Y"0`PYT/0``@WIQL`$.=D0#`.@:>$
M``SG0=``2`:G&P`0YV1`,`Z!IW3_^.?F``<$(4%0,`&YA`!.N2``0[GB(!6G
M)``8XR%/\/]Q["S^KP-]XQ+?_/]QP#````1LIP@``+)=`#&G%/_^N>*`;:?T
M_IZG.0`/I_3_T:?I``^G]/T`P"````1:P.7___F$!P?K?_`X`"2R3P"PP*``
M`#%CZ[L`(``-XQ"@```$LD\`L;D$`._C\/]0_W'CX/```"32!_"HL"CCD;``
M``1!@/"DP"````-WT@"0L9"PN00`.,#E___NJ.PH``<`?)4Q(`"GA`#2P.7_
M__8^XR"@```$XY*P```$N00`*:=9``.G20`!P#````0PP.7__][<N00`DNPH
M`!\`?.,P(!``!.-PH```!.,P,```!.,GL```!,!````$&L#E___>U>-`D!``
M!.,P0```!)%`,`VG=`"SXW"@```$IUD``^,GL```!*=)``'`,```!`/`Y?__
MWJNY!`"2["@`'`!\N00`.,`@```"_<#E___N3KD$`$+L*`"!`'SC$)`0``3C
M)[````3C,!````3`Y?__WIWCH*````2G20`!XWJP```$P#````/8N00`)\#E
M___=[<!````#V[D$`#*Y!``GP.7__]Z#XRJP```$N00`.)(`(+'`(````L#`
MY?__[A;$*P``,1NY!`""["@`+`!\N00`**<Y`<#`Y?__WW?L`@`!`-CL#``6
M`7_L*``3$7[$N```,/^Y!`!2XS"P```$N00`2,`@```#ML#E___?_M4'\*BP
M**=T`#GK?_#H``0'_L0H```PYL#E___ZI\0K```PY+D$`(+L)O_,`'S`(```
M`XC`Y?__W^&5`"`!IX3_-Z?T_RSC4)`0``3$Z```,,GC(%````3C,.````3`
MY?__[\2G]/]_XR>P```$P.7__]]DI_3_2<#E___?;P<'!P<'!P<'ZY_P2``D
MLD\`H+D$`._KJ@`@``VR3P"AX_#_4/]QX^#P```DN00`LD$P\*32!_"HH"C`
M(````F3`Y?__[8SL*``3`'SC$"```)3L&``-`'[L&``*,'[LN``'`'R5`+``
MIW0`"]4'\*B@**=T`#3KG_#X``0'_KD$`"O`Y?__]#NG.0`ON00`DL#E___?
MQ.PH``4`?$&0(`&Y!``IP.7__]Y*ITD`!,`P```"A,#E___=TNPF_]D`?M4'
M\*B@**=T``JY!``KZY_P^``$P/3__^X*P.7__][_!P<'!P<'!P?KW_!H`"3`
MT```(>FY!`#OX_#_8/]QX^#P```DIRD`@,#E___=&.<`T"`P!N<@T!`P!N=`
MT``P!N<`(``P#N<@(!`P#N=`("`P#N5((#```.5,('@``.O?\0@`!`?^!P?K
M;_`P`"2Y!`#OX_#_8/]QX^#P```DXU`@*``$N00`DNL4``,`#;D(`!7L(2"_
M`%6Y!`"$N00`L^-`D#``!+DQ`%&GQ``$ITL``>L(`!T`#+D(``3G`@```&+C
MT)!X`!+G`)`H,`ZG=``^07"0..R,`&,_?NQH_\``V(A@``;LY@`!`-CL7A^Y
M!EGL%?_``-E!U;``ZZ$`!@`,IZL``=(_<`"P`+D$`"E!L+!`P.7__^&"IZ?_
M]J>*_\")8``&&X:Y%`"(N00`/;D$`">Y!`!(P.7__]^`4("0>.MO\-``!`?^
MIZ@`0!NM&:A!<)`XN?(PJ+D$`">Y&``MN00`.[D4`&JY!`!&P.7__]]E&#I:
M,)!X4#"0>.PV_^)`?AN*N00`*;D(`+:Y%`"(P.7__^%#I_3_G[D$`-NG]/_&
M!P<'!^N/\$``),#0```A,;D$`._C\/]@_W'CX/```"3CD#`H``2Y!`"SXX`P
M,``$[#DZOSU9N10`$T%!L#B2@$``ISH``;D$`*)!$+`XN10`([D(`!+L/`!I
M.'ZG2`!`N?DP).Q#`!"`=J<J___K`@`(`-[L!@!Y`'ZY%@!2QE````!]N00`
M*\#E___@]M<WL#BP.&@`T`#KZ``0``SK&``8``SK.``(``SK20`8``SK*0`(
M``SG`0```"+G#@`!`"+G`P`"`"+G"``#`"+KB0`0``SG!``$`"+G"``%`"+G
M`@`&`"+G"0`'`")@`+!PN00`*\#E___@P-(#H`"P!+D$`"O2`Z`$L`S2`Z`(
ML!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__WAFG"``XN?DP4.P#_[*`=J=:___K
MY0`(`-[LY@`*`'ZY%@`UQC`````:I_3_HM?_$``0`$$0$0"GYO_[I_3_\M?_
M$``0`$$0$0"G!O_[I_3_@]<`$``0`-<`$``0`,18```N9,#T___;I0<'!P?K
M;_`P`"3C$/!X``2G^_]@XQ#P```DP,```"TQXT#Q$``$ZV_PT``$!_0`````
M`````@`!)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4```O<')O8R]S96QF+V5X90``+W!R;V,O)6DO)7,`
M97AE`"X`4$%27U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!0
M15),3$E"`%!%4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/
M0D%,7T1%0E5'``!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``,0!L<V5E:R!F86EL960`
M`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@``"5S
M)7,E<R5S``!P87(M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(``!P87)L```N<&%R``!S:&]R
M="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N
M,#8S`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@
M>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ
M92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD
M4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA
M9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P
M,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S
M:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%
M.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P
M;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I
M(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D
M<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$[
M"GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L
M94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N
M86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*
M8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@
M(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]
M("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?
M<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I
M('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)
M0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H
M(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#
M04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#
M3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@
M34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`[
M"G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E
M="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R
M="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?
M1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E
M860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C
M:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)
M3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L
M94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D
M(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D[
M"B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[
M8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U
M9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T
M97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U
M9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S
M("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@
M9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@
M/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY
M("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M
M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I
M.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W
M)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD
M8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,
M12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N
M="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B
M)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]
M"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z
M:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2![
M"B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D
M("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F
M:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE
M7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ
M92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL
M"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E
M<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@
M;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P
M<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&
M24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B
M=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N
M86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE
M.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B([
M"GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D
M:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@
M)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?
M=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP
M;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@
M*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M
M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P
M=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!
M4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@
M97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M55-%4@``55-%4DY!344``%1%35!$25(`5$U0`"]T;7```````````,/2X?``
M``````````````"8NMS^`````!`R5'8`````9T4C`0````#OS:N)````````
M``!P97)L>'-I+F,``$-!0TA%```````````!&P,[````[````!S__WPH```&
M'/__?K@```$(__]_Z````3C__Y9(```!>/__ES@```'8__^7V````@C__YG8
M```"1/__FE@```*`__^;6````KS__YZH```"_/__GN@```,0__^?V````TS_
M_Y_H```#8/__HZ@```.<__^CZ````\C__Z6(```$#/__JR@```1`__^KJ```
M!'#__ZPX```$G/__K@@```38__^N2```!/C__Z_8```%1/__N*@```6<__^Z
M^```!=C__[O8```&7/__O#@```:`__^]>```!KS__[[X```&^``````````4
M``````%Z4@`!>`X!&PP/H`$'#@`````4````'/__?:@```!"````````````
M```4``````%Z4@`!>`X!&PP/H`$````````\````'/__?J@``!9:`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!4X.T`<#%CX*S\[-S,O*R<C'Q@Z@`4(+````````
M7````%S__Y3(````Y@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#L`"`IX*S\[-
MS,O*R<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!0@M."L_.S<S+RLG(Q\8.H`%"
M"P``````+````+S__Y58````F@!&B@J+"8P(C0>.!H\%6`[8`P)T"L_.S<S+
MR@Z@`4(+````.````.S__Y7(```!_@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP58
M#N`#;@K/SLW,R\K)R,?&#J`!0@L`````.````2C__Y>,````?@!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5D#L@"`E+/SLW,R\K)R,?&#J`!````````.````63_
M_Y?0````^`!&APV(#(D+B@J+"8P(C0>.!H\%6`[((@*,"L_.S<S+RLG(QPZ@
M`4(+````````/````:#__YB4```#2@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP58
M#N`"`P*@"L_.S<S+RLG(Q\8.H`%""P```````!````'@__^;I````#@`````
M````.````?3__YO0````Z@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP58#MA"`KP*
MS\[-S,O*R<C'Q@Z@`4(+````$````C#__YR$````!@`````````X```"1/__
MG(````.V`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.\",";`K/SLW,R\K)R,?&
M#J`!0@L````H```"@/__H`0````^`$:+"8P(C0>.!H\%2@[``FC/SLW,RPZ@
M`0```````$````*L__^@&````9(`1HD+B@J+"8P(C0>.!H\%6`[((@,!.@K/
MSLW,R\K)#J`!0@MD"L_.S<S+RLD.H`%&"P``````,````O#__Z%T```%E@!&
MB@J+"8P(C0>.!H\%6`[0`@,%0@K/SLW,R\H.H`%&"P```````"P```,D__^F
MX````(``1HL)C`B-!XX&CP58#M`"`E(*S\[-S,L.H`%""P```````"@```-4
M__^G,````((`8(8.APV(#(D+B@J+"8P(C0>.!H\%2@[H`@``````.````X#_
M_Z>4```!R`!&APV(#(D+B@J+"8P(C0>.!H\%6`[0@@0#`7X*S\[-S,O*R<C'
M#J`!0@L`````'````[S__ZDH````-@!&C@:/!4H.P`)DS\X.H`$```!(```#
MW/__J4@```&0`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.X`("3`K/SLW,R\K)
MR,?&#J`!1@L#`1K/SLW,R\K)R,?&#J`!````5```!"C__ZJ,```(S@!*A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5*#O@$3I@5`P-V"L_.S<S+RLG(Q\;8#J`!1@L#
M`4H*S\[-S,O*R<C'QM@.H`%""P```````#@```2`__^S!````D@`1H<-B`R)
M"XH*BPF,"(T'C@:/!60.T`(#`;`*S\[-S,O*R<C'#J`!0@L``````$````2\
M__^U&````-@`1HD+B@J+"8P(C0>.!H\%6`[0`@)6"L_.S<S+RLD.H`%""P)6
M"L_.S<S+RLD.H`%&"P``````/```!0#__W8$```"D`!&A@Z'#8@,B0N*"HL)
MC`B-!XX&CP58#N@"`P&^"L_.S<S+RLG(Q\8.H`%""P```````"````5`__^U
M=````%X`1HT'C@:/!5`.P`("1L_.S0Z@`0```#@```5D__^UL````3P`1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%2@[``@+0"L_.S<S+RLG(Q\8.H`%""P```#@`
M``6@__^VM````8``1H@,B0N*"HL)C`B-!XX&CP50#L`"`P$("L_.S<S+RLG(
M#J`!1@L``````````!````7<__^W^`````P`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"0@````````(]```````````0````````+:``````````$````````"Z@``
M```````,````````&5``````````#0```````&-0`````````!D```````"[
MN``````````;``````````@`````````&@```````+O``````````!P`````
M````"`````!O__[U`````````I``````````!0````````PH``````````8`
M```````#<``````````*````````!&8`````````"P`````````8````````
M`!4````````````````````#````````O<@``````````@````````40````
M`````!0`````````!P`````````7````````%$``````````!P```````!&X
M``````````@````````"B``````````)`````````!@`````````'@``````
M```(`````&____L`````"````0````!O___^````````$4@`````;____P``
M```````!`````&____`````````0C@````!O___Y`````````!``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````+O(````````````
M`````````````````!F^````````&=X````````9_@```````!H>````````
M&CX````````:7@```````!I^````````&IX````````:O@```````!K>````
M````&OX````````;'@```````!L^````````&UX````````;?@```````!N>
M````````&[X````````;W@```````!O^````````'!X````````</@``````
M`!Q>````````''X````````<G@```````!R^````````'-X````````<_@``
M`````!T>````````'3X````````=7@```````!U^````````'9X````````=
MO@```````!W>````````'?X````````>'@```````!X^````````'EX`````
M```>?@```````!Z>````````'KX````````>W@```````![^````````'QX`
M```````?/@```````!]>````````'WX````````?G@```````!^^````````
M']X````````?_@```````"`>````````(#X````````@7@``````````````
M`````````````````````````%SP````````````````````````````````
M``````````````````````````````````````````````````#`@```````
M````````````('```````````````````,`("E!!4BYP;0H`````````````
M`````*/P````````8]P``````````````````&1\````````9(````````"C
MY````````&/B````````H^P``````````````````*/4````````H]H`````
M`````````````&9D1T-#.B`H56)U;G1U(#$S+C(N,"TR,W5B=6YT=30I(#$S
M+C(N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN
M;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M````````````````````````````````````````````````"P````$`````
M`````@````````(X`````````C@`````````#P````````````````````$`
M`````````````!,````'``````````(````````"2`````````)(````````
M`"0````````````````````$```````````````F````!P`````````"````
M`````FP````````";``````````@````````````````````!```````````
M````-&____8``````````@````````*0`````````I``````````W`````4`
M``````````````@``````````````#X````+``````````(````````#<```
M``````-P````````"+@````&`````@`````````(`````````!@```!&````
M`P`````````"````````#"@````````,*`````````1F````````````````
M`````0``````````````3F____\``````````@```````!".````````$(X`
M````````N@````4```````````````(``````````@```%MO___^````````
M``(````````12````````!%(`````````'`````&`````0`````````(````
M``````````!J````!``````````"````````$;@````````1N`````````*(
M````!0``````````````"``````````8````=`````0`````````0@``````
M`!1`````````%$`````````%$`````4````5``````````@`````````&```
M`'X````!``````````8````````94````````!E0`````````#X`````````
M```````````$``````````````!Y`````0`````````&````````&9``````
M```9D`````````;@````````````````````!``````````@````A`````$`
M````````!@```````"!P````````('````````!"X```````````````````
M`!```````````````(H````!``````````8```````!C4````````&-0````
M`````"H````````````````````$``````````````"0`````0`````````"
M````````8X````````!C@````````$#(````````````````````"```````
M````````F`````$``````````@```````*1(````````I$@`````````[```
M``````````````````0``````````````*8````!``````````(```````"E
M.````````*4X````````!B`````````````````````(``````````````"P
M````#@`````````#````````N[@```````"KN``````````(````````````
M````````"``````````(````O`````\``````````P```````+O`````````
MJ\``````````"`````````````````````@`````````"````,@````&````
M``````,```````"[R````````*O(`````````@`````&```````````````(
M`````````!````#1`````0`````````#````````O<@```````"MR```````
M``(X````````````````````"``````````(````U@````$``````````P``
M`````,``````````L```````````B`````````````````````@`````````
M`````-P````(``````````,```````#`B````````+"(`````````"@`````
M```````````````(``````````````#A`````0`````````P````````````
M``````"PB``````````F`````````````````````0`````````!`````0``
M``,`````````````````````````````L*X`````````Z@``````````````
-``````$`````````````
